@@ -25,5 +25,7 @@ import org.junit.jupiter.api.Tag;
 public class CatalogMysqlDriverIT extends CatalogMysqlIT {
   public CatalogMysqlDriverIT() {
     super();
+    DOWNLOAD_MYSQL_JDBC_DRIVER_URL =
+        "https://repo1.maven.org/maven2/mysql/mysql-connector-java/8.0.11/mysql-connector-java-8.0.11.jar";
   }
 }
