@@ -20,6 +20,7 @@ package org.apache.gravitino.client;
 
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableMap;
+import com.google.common.collect.Sets;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
@@ -27,6 +28,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
 import java.util.stream.Collectors;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.gravitino.Catalog;
@@ -255,7 +257,10 @@ public class GravitinoMetalake extends MetalakeDTO
 
     CatalogResponse resp =
         restClient.put(
-            String.format(API_METALAKES_CATALOGS_PATH, this.name(), catalogName),
+            String.format(
+                API_METALAKES_CATALOGS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(catalogName)),
             updatesRequest,
             CatalogResponse.class,
             Collections.emptyMap(),
@@ -289,7 +294,10 @@ public class GravitinoMetalake extends MetalakeDTO
 
     DropResponse resp =
         restClient.delete(
-            String.format(API_METALAKES_CATALOGS_PATH, this.name(), catalogName),
+            String.format(
+                API_METALAKES_CATALOGS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(catalogName)),
             params,
             DropResponse.class,
             Collections.emptyMap(),
@@ -304,7 +312,10 @@ public class GravitinoMetalake extends MetalakeDTO
 
     ErrorResponse resp =
         restClient.patch(
-            String.format(API_METALAKES_CATALOGS_PATH, this.name(), catalogName),
+            String.format(
+                API_METALAKES_CATALOGS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(catalogName)),
             req,
             ErrorResponse.class,
             Collections.emptyMap(),
@@ -323,7 +334,10 @@ public class GravitinoMetalake extends MetalakeDTO
 
     ErrorResponse resp =
         restClient.patch(
-            String.format(API_METALAKES_CATALOGS_PATH, this.name(), catalogName),
+            String.format(
+                API_METALAKES_CATALOGS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(catalogName)),
             req,
             ErrorResponse.class,
             Collections.emptyMap(),
@@ -364,7 +378,8 @@ public class GravitinoMetalake extends MetalakeDTO
     // only)
     ErrorResponse resp =
         restClient.post(
-            String.format("api/metalakes/%s/catalogs/testConnection", this.name()),
+            String.format(
+                "api/metalakes/%s/catalogs/testConnection", RESTUtils.encodeString(this.name())),
             req,
             ErrorResponse.class,
             Collections.emptyMap(),
@@ -393,7 +408,7 @@ public class GravitinoMetalake extends MetalakeDTO
   public String[] listTags() throws NoSuchMetalakeException {
     NameListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_TAGS_PATH, this.name()),
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name())),
             NameListResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.tagErrorHandler());
@@ -412,7 +427,7 @@ public class GravitinoMetalake extends MetalakeDTO
     Map<String, String> params = ImmutableMap.of("details", "true");
     TagListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_TAGS_PATH, this.name()),
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name())),
             params,
             TagListResponse.class,
             Collections.emptyMap(),
@@ -437,7 +452,9 @@ public class GravitinoMetalake extends MetalakeDTO
 
     TagResponse resp =
         restClient.get(
-            String.format(API_METALAKES_TAGS_PATH, this.name()) + "/" + name,
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name()))
+                + "/"
+                + RESTUtils.encodeString(name),
             TagResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.tagErrorHandler());
@@ -464,7 +481,7 @@ public class GravitinoMetalake extends MetalakeDTO
 
     TagResponse resp =
         restClient.post(
-            String.format(API_METALAKES_TAGS_PATH, this.name()),
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name())),
             req,
             TagResponse.class,
             Collections.emptyMap(),
@@ -494,7 +511,9 @@ public class GravitinoMetalake extends MetalakeDTO
 
     TagResponse resp =
         restClient.put(
-            String.format(API_METALAKES_TAGS_PATH, this.name()) + "/" + name,
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name()))
+                + "/"
+                + RESTUtils.encodeString(name),
             req,
             TagResponse.class,
             Collections.emptyMap(),
@@ -516,7 +535,9 @@ public class GravitinoMetalake extends MetalakeDTO
 
     DropResponse resp =
         restClient.delete(
-            String.format(API_METALAKES_TAGS_PATH, this.name()) + "/" + name,
+            String.format(API_METALAKES_TAGS_PATH, RESTUtils.encodeString(this.name()))
+                + "/"
+                + RESTUtils.encodeString(name),
             DropResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.tagErrorHandler());
@@ -539,7 +560,8 @@ public class GravitinoMetalake extends MetalakeDTO
 
     UserResponse resp =
         restClient.post(
-            String.format(API_METALAKES_USERS_PATH, this.name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_USERS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             req,
             UserResponse.class,
             Collections.emptyMap(),
@@ -561,7 +583,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public boolean removeUser(String user) throws NoSuchMetalakeException {
     RemoveResponse resp =
         restClient.delete(
-            String.format(API_METALAKES_USERS_PATH, this.name(), RESTUtils.encodeString(user)),
+            String.format(
+                API_METALAKES_USERS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(user)),
             RemoveResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.userErrorHandler());
@@ -582,7 +607,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public User getUser(String user) throws NoSuchUserException, NoSuchMetalakeException {
     UserResponse resp =
         restClient.get(
-            String.format(API_METALAKES_USERS_PATH, this.name(), RESTUtils.encodeString(user)),
+            String.format(
+                API_METALAKES_USERS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(user)),
             UserResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.userErrorHandler());
@@ -603,7 +631,8 @@ public class GravitinoMetalake extends MetalakeDTO
 
     UserListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_USERS_PATH, name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_USERS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             params,
             UserListResponse.class,
             Collections.emptyMap(),
@@ -622,7 +651,8 @@ public class GravitinoMetalake extends MetalakeDTO
   public String[] listUserNames() throws NoSuchMetalakeException {
     NameListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_USERS_PATH, name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_USERS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             NameListResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.userErrorHandler());
@@ -646,7 +676,8 @@ public class GravitinoMetalake extends MetalakeDTO
 
     GroupResponse resp =
         restClient.post(
-            String.format(API_METALAKES_GROUPS_PATH, this.name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_GROUPS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             req,
             GroupResponse.class,
             Collections.emptyMap(),
@@ -668,7 +699,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public boolean removeGroup(String group) throws NoSuchMetalakeException {
     RemoveResponse resp =
         restClient.delete(
-            String.format(API_METALAKES_GROUPS_PATH, this.name(), RESTUtils.encodeString(group)),
+            String.format(
+                API_METALAKES_GROUPS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(group)),
             RemoveResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.groupErrorHandler());
@@ -689,7 +723,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public Group getGroup(String group) throws NoSuchGroupException, NoSuchMetalakeException {
     GroupResponse resp =
         restClient.get(
-            String.format(API_METALAKES_GROUPS_PATH, this.name(), RESTUtils.encodeString(group)),
+            String.format(
+                API_METALAKES_GROUPS_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(group)),
             GroupResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.groupErrorHandler());
@@ -710,7 +747,8 @@ public class GravitinoMetalake extends MetalakeDTO
 
     GroupListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_GROUPS_PATH, name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_GROUPS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             params,
             GroupListResponse.class,
             Collections.emptyMap(),
@@ -728,7 +766,8 @@ public class GravitinoMetalake extends MetalakeDTO
   public String[] listGroupNames() throws NoSuchMetalakeException {
     NameListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_GROUPS_PATH, name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_GROUPS_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             NameListResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.groupErrorHandler());
@@ -748,7 +787,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public Role getRole(String role) throws NoSuchRoleException, NoSuchMetalakeException {
     RoleResponse resp =
         restClient.get(
-            String.format(API_METALAKES_ROLES_PATH, this.name(), RESTUtils.encodeString(role)),
+            String.format(
+                API_METALAKES_ROLES_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(role)),
             RoleResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.roleErrorHandler());
@@ -769,7 +811,10 @@ public class GravitinoMetalake extends MetalakeDTO
   public boolean deleteRole(String role) throws NoSuchMetalakeException {
     DeleteResponse resp =
         restClient.delete(
-            String.format(API_METALAKES_ROLES_PATH, this.name(), RESTUtils.encodeString(role)),
+            String.format(
+                API_METALAKES_ROLES_PATH,
+                RESTUtils.encodeString(this.name()),
+                RESTUtils.encodeString(role)),
             DeleteResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.roleErrorHandler());
@@ -804,7 +849,8 @@ public class GravitinoMetalake extends MetalakeDTO
 
     RoleResponse resp =
         restClient.post(
-            String.format(API_METALAKES_ROLES_PATH, this.name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_ROLES_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             req,
             RoleResponse.class,
             Collections.emptyMap(),
@@ -823,7 +869,8 @@ public class GravitinoMetalake extends MetalakeDTO
   public String[] listRoleNames() {
     NameListResponse resp =
         restClient.get(
-            String.format(API_METALAKES_ROLES_PATH, this.name(), BLANK_PLACEHOLDER),
+            String.format(
+                API_METALAKES_ROLES_PATH, RESTUtils.encodeString(this.name()), BLANK_PLACEHOLDER),
             NameListResponse.class,
             Collections.emptyMap(),
             ErrorHandlers.roleErrorHandler());
@@ -852,7 +899,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format("users/%s/grant", RESTUtils.encodeString(user))),
             request,
             UserResponse.class,
@@ -883,7 +930,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format("groups/%s/grant", RESTUtils.encodeString(group))),
             request,
             GroupResponse.class,
@@ -914,7 +961,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format("users/%s/revoke", RESTUtils.encodeString(user))),
             request,
             UserResponse.class,
@@ -945,7 +992,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format("groups/%s/revoke", RESTUtils.encodeString(group))),
             request,
             GroupResponse.class,
@@ -973,6 +1020,27 @@ public class GravitinoMetalake extends MetalakeDTO
   public Role grantPrivilegesToRole(String role, MetadataObject object, List<Privilege> privileges)
       throws NoSuchRoleException, NoSuchMetadataObjectException, NoSuchMetalakeException,
           IllegalPrivilegeException {
+    Set<Privilege> privilegeSet = Sets.newHashSet(privileges);
+    return grantPrivilegesToRole(role, object, privilegeSet);
+  }
+
+  /**
+   * Grant privileges to a role.
+   *
+   * @param role The name of the role.
+   * @param privileges The privileges to grant.
+   * @param object The object is associated with privileges to grant.
+   * @return The role after granted.
+   * @throws NoSuchRoleException If the role with the given name does not exist.
+   * @throws NoSuchMetadataObjectException If the metadata object with the given name does not
+   *     exist.
+   * @throws NoSuchMetalakeException If the Metalake with the given name does not exist.
+   * @throws IllegalPrivilegeException If any privilege can't be bind to the metadata object.
+   * @throws RuntimeException If granting privileges to a role encounters storage issues.
+   */
+  public Role grantPrivilegesToRole(String role, MetadataObject object, Set<Privilege> privileges)
+      throws NoSuchRoleException, NoSuchMetadataObjectException, NoSuchMetalakeException,
+          IllegalPrivilegeException {
     PrivilegeGrantRequest request =
         new PrivilegeGrantRequest(DTOConverters.toPrivileges(privileges));
     request.validate();
@@ -981,12 +1049,12 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format(
                     "roles/%s/%s/%s/grant",
                     RESTUtils.encodeString(role),
                     object.type().name().toLowerCase(Locale.ROOT),
-                    object.fullName())),
+                    RESTUtils.encodeString(object.fullName()))),
             request,
             RoleResponse.class,
             Collections.emptyMap(),
@@ -1011,10 +1079,33 @@ public class GravitinoMetalake extends MetalakeDTO
    * @throws IllegalPrivilegeException If any privilege can't be bind to the metadata object.
    * @throws RuntimeException If revoking privileges from a role encounters storage issues.
    */
+  @Deprecated
   public Role revokePrivilegesFromRole(
       String role, MetadataObject object, List<Privilege> privileges)
       throws NoSuchRoleException, NoSuchMetadataObjectException, NoSuchMetalakeException,
           IllegalPrivilegeException {
+    Set<Privilege> privilegeSet = Sets.newHashSet(privileges);
+    return revokePrivilegesFromRole(role, object, privilegeSet);
+  }
+
+  /**
+   * Revoke privileges from a role.
+   *
+   * @param role The name of the role.
+   * @param privileges The privileges to revoke.
+   * @param object The object is associated with privileges to revoke.
+   * @return The role after revoked.
+   * @throws NoSuchRoleException If the role with the given name does not exist.
+   * @throws NoSuchMetadataObjectException If the metadata object with the given name does not
+   *     exist.
+   * @throws NoSuchMetalakeException If the Metalake with the given name does not exist.
+   * @throws IllegalPrivilegeException If any privilege can't be bind to the metadata object.
+   * @throws RuntimeException If revoking privileges from a role encounters storage issues.
+   */
+  public Role revokePrivilegesFromRole(
+      String role, MetadataObject object, Set<Privilege> privileges)
+      throws NoSuchRoleException, NoSuchMetadataObjectException, NoSuchMetalakeException,
+          IllegalPrivilegeException {
     PrivilegeRevokeRequest request =
         new PrivilegeRevokeRequest(DTOConverters.toPrivileges(privileges));
     request.validate();
@@ -1023,12 +1114,12 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_PERMISSION_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format(
                     "roles/%s/%s/%s/revoke",
                     RESTUtils.encodeString(role),
                     object.type().name().toLowerCase(Locale.ROOT),
-                    object.fullName())),
+                    RESTUtils.encodeString(object.fullName()))),
             request,
             RoleResponse.class,
             Collections.emptyMap(),
@@ -1052,7 +1143,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.get(
             String.format(
                 API_METALAKES_OWNERS_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format(
                     "%s/%s",
                     object.type().name().toLowerCase(Locale.ROOT),
@@ -1080,7 +1171,7 @@ public class GravitinoMetalake extends MetalakeDTO
         restClient.put(
             String.format(
                 API_METALAKES_OWNERS_PATH,
-                this.name(),
+                RESTUtils.encodeString(this.name()),
                 String.format(
                     "%s/%s",
                     object.type().name().toLowerCase(Locale.ROOT),
