@@ -22,6 +22,7 @@ from gravitino.exceptions.base import (
     NoSuchFilesetException,
     NoSuchSchemaException,
     CatalogNotInUseException,
+    NoSuchLocationNameException,
 )
 
 
@@ -38,6 +39,8 @@ class FilesetErrorHandler(RestErrorHandler):
                 raise NoSuchSchemaException(error_message)
             if exception_type == NoSuchFilesetException.__name__:
                 raise NoSuchFilesetException(error_message)
+            if exception_type == NoSuchLocationNameException.__name__:
+                raise NoSuchLocationNameException(error_message)
 
         if code == ErrorConstants.NOT_IN_USE_CODE:
             raise CatalogNotInUseException(error_message)
