@@ -16,14 +16,12 @@
 # under the License.
 import base64
 import os
-
-# pylint: disable=protected-access,too-many-lines,too-many-locals
-
 import random
 import string
 import time
 import unittest
 from datetime import datetime
+from unittest import mock
 from unittest.mock import patch
 
 import pandas
@@ -32,7 +30,7 @@ import pyarrow.dataset as dt
 import pyarrow.parquet as pq
 from fsspec.implementations.local import LocalFileSystem
 
-from gravitino import gvfs, NameIdentifier
+from gravitino import gvfs, NameIdentifier, Fileset
 from gravitino.auth.auth_constants import AuthConstants
 from gravitino.exceptions.base import (
     GravitinoRuntimeException,
@@ -40,6 +38,8 @@ from gravitino.exceptions.base import (
     BadRequestException,
 )
 from gravitino.filesystem.gvfs_config import GVFSConfig
+from gravitino.filesystem.gvfs_storage_handler import LOCA_HANDLER
+from gravitino.filesystem.gvfs_utils import extract_identifier, to_gvfs_path_prefix
 from tests.unittests import mock_base
 from tests.unittests.auth.mock_base import (
     mock_jwt,
@@ -49,6 +49,9 @@ from tests.unittests.auth.mock_base import (
 )
 
 
+# pylint: disable=protected-access,too-many-lines,too-many-locals
+
+
 # pylint: disable=C0302
 def generate_unique_random_string(length):
     characters = string.ascii_letters + string.digits
@@ -56,8 +59,14 @@ def generate_unique_random_string(length):
     return random_string
 
 
+@patch(
+    "gravitino.client.generic_fileset.GenericFileset.get_credentials",
+    return_value=[],
+)
 @mock_base.mock_data
 class TestLocalFilesystem(unittest.TestCase):
+    _metalake_name: str = "metalake_demo"
+    _server_uri = "http://localhost:9090"
     _local_base_dir_path: str = "file:/tmp/fileset"
     _fileset_dir: str = (
         f"{_local_base_dir_path}/{generate_unique_random_string(10)}/fileset_catalog/tmp"
@@ -73,28 +82,53 @@ class TestLocalFilesystem(unittest.TestCase):
         if local_fs.exists(self._local_base_dir_path):
             local_fs.rm(self._local_base_dir_path, recursive=True)
 
+    def test_request_headers(self, *mock_methods):
+        options = {
+            f"{GVFSConfig.GVFS_FILESYSTEM_CLIENT_REQUEST_HEADER_PREFIX}k1": "v1",
+        }
+        fs = gvfs.GravitinoVirtualFileSystem(
+            server_uri="http://localhost:9090",
+            metalake_name="metalake_demo",
+            options=options,
+            skip_instance_cache=True,
+        )
+        headers = fs._operations._client._rest_client.request_headers
+        self.assertEqual(headers["k1"], "v1")
+
     def test_cache(self, *mock_methods):
         fileset_storage_location = f"{self._fileset_dir}/test_cache"
         fileset_virtual_location = "fileset/fileset_catalog/tmp/test_cache"
         actual_path = fileset_storage_location
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "test_cache", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             local_fs = LocalFileSystem()
             local_fs.mkdir(fileset_storage_location)
             self.assertTrue(local_fs.exists(fileset_storage_location))
             options = {GVFSConfig.CACHE_SIZE: 1, GVFSConfig.CACHE_EXPIRED_TIME: 1}
             fs = gvfs.GravitinoVirtualFileSystem(
-                server_uri="http://localhost:9090",
-                metalake_name="metalake_demo",
+                server_uri=self._server_uri,
+                metalake_name=self._metalake_name,
                 options=options,
                 skip_instance_cache=True,
             )
             self.assertTrue(fs.exists(fileset_virtual_location))
             # wait 2 seconds
             time.sleep(2)
-            self.assertIsNone(fs._cache.get("file:/"))
+            name_identifier = NameIdentifier.of(
+                self._metalake_name, "fileset_catalog", "tmp", "test_cache"
+            )
+            self.assertIsNone(
+                fs._operations._filesystem_cache.get(
+                    (name_identifier, Fileset.LOCATION_NAME_UNKNOWN)
+                )
+            )
 
     def test_simple_auth(self, *mock_methods):
         options = {"auth_type": "simple"}
@@ -104,12 +138,12 @@ class TestLocalFilesystem(unittest.TestCase):
         user = "test_gvfs"
         os.environ["user.name"] = user
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             options=options,
             skip_instance_cache=True,
         )
-        token = fs._client._rest_client.auth_data_provider.get_token_data()
+        token = fs._operations._client._rest_client.auth_data_provider.get_token_data()
         token_string = base64.b64decode(
             token.decode("utf-8")[len(AuthConstants.AUTHORIZATION_BASIC_HEADER) :]
         ).decode("utf-8")
@@ -139,9 +173,14 @@ class TestLocalFilesystem(unittest.TestCase):
             fileset_storage_location = f"{self._fileset_dir}/test_oauth2_auth"
             fileset_virtual_location = "fileset/fileset_catalog/tmp/test_oauth2_auth"
             actual_path = fileset_storage_location
-            with patch(
-                "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-                return_value=actual_path,
+            with patch.multiple(
+                "gravitino.client.fileset_catalog.FilesetCatalog",
+                load_fileset=mock.MagicMock(
+                    return_value=mock_base.mock_load_fileset(
+                        "fileset", fileset_storage_location
+                    )
+                ),
+                get_file_location=mock.MagicMock(return_value=actual_path),
             ):
                 local_fs = LocalFileSystem()
                 local_fs.mkdir(fileset_storage_location)
@@ -152,8 +191,8 @@ class TestLocalFilesystem(unittest.TestCase):
                 local_fs.touch(sub_file_path)
                 self.assertTrue(local_fs.exists(sub_file_path))
                 fs = gvfs.GravitinoVirtualFileSystem(
-                    server_uri="http://localhost:9090",
-                    metalake_name="metalake_demo",
+                    server_uri=self._server_uri,
+                    metalake_name=self._metalake_name,
                     options=fs_options,
                     skip_instance_cache=True,
                 )
@@ -167,8 +206,8 @@ class TestLocalFilesystem(unittest.TestCase):
         ):
             with self.assertRaises(IllegalArgumentException):
                 gvfs.GravitinoVirtualFileSystem(
-                    server_uri="http://localhost:9090",
-                    metalake_name="metalake_demo",
+                    server_uri=self._server_uri,
+                    metalake_name=self._metalake_name,
                     options=fs_options,
                     skip_instance_cache=True,
                 )
@@ -180,8 +219,8 @@ class TestLocalFilesystem(unittest.TestCase):
         ):
             with self.assertRaises(BadRequestException):
                 gvfs.GravitinoVirtualFileSystem(
-                    server_uri="http://localhost:9090",
-                    metalake_name="metalake_demo",
+                    server_uri=self._server_uri,
+                    metalake_name=self._metalake_name,
                     options=fs_options,
                     skip_instance_cache=True,
                 )
@@ -190,9 +229,14 @@ class TestLocalFilesystem(unittest.TestCase):
         fileset_storage_location = f"{self._fileset_dir}/test_ls"
         fileset_virtual_location = "fileset/fileset_catalog/tmp/test_ls"
         actual_path = fileset_storage_location
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             local_fs = LocalFileSystem()
             local_fs.mkdir(fileset_storage_location)
@@ -204,8 +248,8 @@ class TestLocalFilesystem(unittest.TestCase):
             self.assertTrue(local_fs.exists(sub_file_path))
 
             fs = gvfs.GravitinoVirtualFileSystem(
-                server_uri="http://localhost:9090",
-                metalake_name="metalake_demo",
+                server_uri=self._server_uri,
+                metalake_name=self._metalake_name,
                 skip_instance_cache=True,
             )
             self.assertTrue(fs.exists(fileset_virtual_location))
@@ -248,13 +292,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_file_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -290,29 +339,44 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_file_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
         dir_virtual_path = fileset_virtual_location + "/test_1"
         actual_path = fileset_storage_location + "/test_1"
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(dir_virtual_path))
 
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         actual_path = fileset_storage_location + "/test_file_1.par"
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(file_virtual_path))
 
@@ -330,13 +394,18 @@ class TestLocalFilesystem(unittest.TestCase):
             f.write(b"test_file_1")
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -351,6 +420,11 @@ class TestLocalFilesystem(unittest.TestCase):
                 dst_actual_path,
                 dst_actual_path,
             ],
+        ), patch(
+            "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+            return_value=mock_base.mock_load_fileset(
+                "fileset", fileset_storage_location
+            ),
         ):
             self.assertTrue(fs.exists(file_virtual_path))
             cp_file_virtual_path = fileset_virtual_location + "/test_cp_file_1.par"
@@ -382,21 +456,31 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(another_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
         file_virtual_path = fileset_virtual_location + "/test_file_1.par"
         src_actual_path = fileset_storage_location + "/test_file_1.par"
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=src_actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=src_actual_path),
         ):
             self.assertTrue(fs.exists(file_virtual_path))
 
@@ -405,6 +489,11 @@ class TestLocalFilesystem(unittest.TestCase):
         with patch(
             "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[src_actual_path, dst_actual_path, dst_actual_path],
+        ), patch(
+            "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+            return_value=mock_base.mock_load_fileset(
+                "fileset", fileset_storage_location
+            ),
         ):
             fs.mv(file_virtual_path, mv_file_virtual_path)
             self.assertTrue(fs.exists(mv_file_virtual_path))
@@ -416,6 +505,11 @@ class TestLocalFilesystem(unittest.TestCase):
         with patch(
             "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[dst_actual_path, dst_actual_path1, dst_actual_path1],
+        ), patch(
+            "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+            return_value=mock_base.mock_load_fileset(
+                "fileset", fileset_storage_location
+            ),
         ):
             fs.mv(mv_file_virtual_path, mv_another_dir_virtual_path)
             self.assertTrue(fs.exists(mv_another_dir_virtual_path))
@@ -426,6 +520,11 @@ class TestLocalFilesystem(unittest.TestCase):
         with patch(
             "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[dst_actual_path1, dst_actual_path2],
+        ), patch(
+            "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+            return_value=mock_base.mock_load_fileset(
+                "fileset", fileset_storage_location
+            ),
         ):
             with self.assertRaises(FileNotFoundError):
                 fs.mv(path1=mv_another_dir_virtual_path, path2=not_exist_dst_dir_path)
@@ -452,13 +551,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -504,13 +608,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -551,13 +660,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -598,13 +712,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -646,13 +765,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -695,13 +819,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -733,13 +862,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -764,13 +898,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -799,13 +938,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -851,13 +995,18 @@ class TestLocalFilesystem(unittest.TestCase):
         self.assertTrue(local_fs.exists(sub_dir_path))
 
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
@@ -898,23 +1047,20 @@ class TestLocalFilesystem(unittest.TestCase):
             fs.get_file(file_virtual_path, remote_path)
 
     def test_convert_actual_path(self, *mock_methods):
-        fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
-            skip_instance_cache=True,
-        )
-        storage_location = "hdfs://localhost:8090/fileset/test_f1"
-        virtual_location = fs._get_virtual_location(
+        storage_location = "file:/fileset/test_f1"
+        virtual_location = to_gvfs_path_prefix(
             NameIdentifier.of("test_metalake", "test_catalog", "test_schema", "test_f1")
         )
         # test actual path not start with storage location
         actual_path = "/not_start_with_storage/ttt"
         with self.assertRaises(GravitinoRuntimeException):
-            fs._convert_actual_path(actual_path, storage_location, virtual_location)
+            LOCA_HANDLER.actual_path_to_gvfs_path(
+                actual_path, storage_location, virtual_location
+            )
 
         # test actual path start with storage location
         actual_path = "/fileset/test_f1/actual_path"
-        virtual_path = fs._convert_actual_path(
+        virtual_path = LOCA_HANDLER.actual_path_to_gvfs_path(
             actual_path, storage_location, virtual_location
         )
         self.assertEqual(
@@ -922,23 +1068,20 @@ class TestLocalFilesystem(unittest.TestCase):
         )
 
         # test convert actual local path
-        fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
-            skip_instance_cache=True,
-        )
         storage_location = "file:/tmp/fileset/test_f1"
-        virtual_location = fs._get_virtual_location(
+        virtual_location = to_gvfs_path_prefix(
             NameIdentifier.of("test_metalake", "test_catalog", "test_schema", "test_f1")
         )
         # test actual path not start with storage location
         actual_path = "/not_start_with_storage/ttt"
         with self.assertRaises(GravitinoRuntimeException):
-            fs._convert_actual_path(actual_path, storage_location, virtual_location)
+            LOCA_HANDLER.actual_path_to_gvfs_path(
+                actual_path, storage_location, virtual_location
+            )
 
         # test actual path start with storage location
         actual_path = "/tmp/fileset/test_f1/actual_path"
-        virtual_path = fs._convert_actual_path(
+        virtual_path = LOCA_HANDLER.actual_path_to_gvfs_path(
             actual_path, storage_location, virtual_location
         )
         self.assertEqual(
@@ -948,13 +1091,13 @@ class TestLocalFilesystem(unittest.TestCase):
         # test storage location without "/"
         actual_path = "/tmp/test_convert_actual_path/sub_dir/1.parquet"
         storage_location = "file:/tmp/test_convert_actual_path"
-        virtual_location = fs._get_virtual_location(
+        virtual_location = to_gvfs_path_prefix(
             NameIdentifier.of(
                 "test_metalake", "catalog", "schema", "test_convert_actual_path"
             )
         )
 
-        virtual_path = fs._convert_actual_path(
+        virtual_path = LOCA_HANDLER.actual_path_to_gvfs_path(
             actual_path, storage_location, virtual_location
         )
         self.assertEqual(
@@ -965,13 +1108,13 @@ class TestLocalFilesystem(unittest.TestCase):
         # test storage location with "/"
         actual_path = "/tmp/test_convert_actual_path/sub_dir/1.parquet"
         storage_location = "file:/tmp/test_convert_actual_path/"
-        virtual_location = fs._get_virtual_location(
+        virtual_location = to_gvfs_path_prefix(
             NameIdentifier.of(
                 "test_metalake", "catalog", "schema", "test_convert_actual_path"
             )
         )
 
-        virtual_path = fs._convert_actual_path(
+        virtual_path = LOCA_HANDLER.actual_path_to_gvfs_path(
             actual_path, storage_location, virtual_location
         )
         self.assertEqual(
@@ -980,11 +1123,6 @@ class TestLocalFilesystem(unittest.TestCase):
         )
 
     def test_convert_info(self, *mock_methods):
-        fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
-            skip_instance_cache=True,
-        )
         # test actual path not start with storage location
         entry = {
             "name": "/not_start_with_storage/ttt",
@@ -992,12 +1130,14 @@ class TestLocalFilesystem(unittest.TestCase):
             "type": "file",
             "mtime": datetime.now(),
         }
-        storage_location = "hdfs://localhost:8090/fileset/test_f1"
-        virtual_location = fs._get_virtual_location(
+        storage_location = "file:/fileset/test_f1"
+        gvfs_path_prefix = to_gvfs_path_prefix(
             NameIdentifier.of("test_metalake", "test_catalog", "test_schema", "test_f1")
         )
         with self.assertRaises(GravitinoRuntimeException):
-            fs._convert_actual_info(entry, storage_location, virtual_location)
+            LOCA_HANDLER.actual_info_to_gvfs_info(
+                entry, storage_location, gvfs_path_prefix
+            )
 
         # test actual path start with storage location
         entry = {
@@ -1006,17 +1146,14 @@ class TestLocalFilesystem(unittest.TestCase):
             "type": "file",
             "mtime": datetime.now(),
         }
-        info = fs._convert_actual_info(entry, storage_location, virtual_location)
+        info = LOCA_HANDLER.actual_info_to_gvfs_info(
+            entry, storage_location, gvfs_path_prefix
+        )
         self.assertEqual(
             "fileset/test_catalog/test_schema/test_f1/actual_path", info["name"]
         )
 
         # test convert actual local path
-        fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
-            skip_instance_cache=True,
-        )
         # test actual path not start with storage location
         entry = {
             "name": "/not_start_with_storage/ttt",
@@ -1025,11 +1162,13 @@ class TestLocalFilesystem(unittest.TestCase):
             "mtime": datetime.now(),
         }
         storage_location = "file:/tmp/fileset/test_f1"
-        virtual_location = fs._get_virtual_location(
+        gvfs_path_prefix = to_gvfs_path_prefix(
             NameIdentifier.of("test_metalake", "test_catalog", "test_schema", "test_f1")
         )
         with self.assertRaises(GravitinoRuntimeException):
-            fs._convert_actual_info(entry, storage_location, virtual_location)
+            LOCA_HANDLER.actual_info_to_gvfs_info(
+                entry, storage_location, gvfs_path_prefix
+            )
 
         # test actual path start with storage location
         entry = {
@@ -1038,27 +1177,26 @@ class TestLocalFilesystem(unittest.TestCase):
             "type": "file",
             "mtime": datetime.now(),
         }
-        info = fs._convert_actual_info(entry, storage_location, virtual_location)
+        info = LOCA_HANDLER.actual_info_to_gvfs_info(
+            entry, storage_location, gvfs_path_prefix
+        )
         self.assertEqual(
             "fileset/test_catalog/test_schema/test_f1/actual_path", info["name"]
         )
 
     def test_extract_identifier(self, *mock_methods):
-        fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
-            skip_instance_cache=True,
-        )
         with self.assertRaises(GravitinoRuntimeException):
-            fs._extract_identifier(path=None)
+            extract_identifier(self._metalake_name, path=None)
 
         invalid_path = "s3://bucket_1/test_catalog/schema/fileset/ttt"
         with self.assertRaises(GravitinoRuntimeException):
-            fs._extract_identifier(path=invalid_path)
+            extract_identifier(self._metalake_name, path=invalid_path)
 
         valid_path = "fileset/test_catalog/schema/fileset/ttt"
-        identifier: NameIdentifier = fs._extract_identifier(path=valid_path)
-        self.assertEqual("metalake_demo", identifier.namespace().level(0))
+        identifier: NameIdentifier = extract_identifier(
+            self._metalake_name, path=valid_path
+        )
+        self.assertEqual(self._metalake_name, identifier.namespace().level(0))
         self.assertEqual("test_catalog", identifier.namespace().level(1))
         self.assertEqual("schema", identifier.namespace().level(2))
         self.assertEqual("fileset", identifier.name())
@@ -1076,9 +1214,14 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         actual_path = fileset_storage_location + "/test.parquet"
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             # to parquet
             data.to_parquet(fileset_virtual_location + "/test.parquet", filesystem=fs)
@@ -1100,6 +1243,11 @@ class TestLocalFilesystem(unittest.TestCase):
         with patch(
             "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
             side_effect=[actual_path1, actual_path2, actual_path2],
+        ), patch(
+            "gravitino.client.fileset_catalog.FilesetCatalog.load_fileset",
+            return_value=mock_base.mock_load_fileset(
+                "fileset", fileset_storage_location
+            ),
         ):
             # to csv
             data.to_csv(
@@ -1127,9 +1275,14 @@ class TestLocalFilesystem(unittest.TestCase):
             skip_instance_cache=True,
         )
         actual_path = fileset_storage_location + "/test.parquet"
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             # to parquet
             data.to_parquet(fileset_virtual_location + "/test.parquet", filesystem=fs)
@@ -1168,13 +1321,18 @@ class TestLocalFilesystem(unittest.TestCase):
 
         actual_path = fileset_storage_location
         fs = gvfs.GravitinoVirtualFileSystem(
-            server_uri="http://localhost:9090",
-            metalake_name="metalake_demo",
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
             skip_instance_cache=True,
         )
-        with patch(
-            "gravitino.client.fileset_catalog.FilesetCatalog.get_file_location",
-            return_value=actual_path,
+        with patch.multiple(
+            "gravitino.client.fileset_catalog.FilesetCatalog",
+            load_fileset=mock.MagicMock(
+                return_value=mock_base.mock_load_fileset(
+                    "fileset", fileset_storage_location
+                )
+            ),
+            get_file_location=mock.MagicMock(return_value=actual_path),
         ):
             self.assertTrue(fs.exists(fileset_virtual_location))
 
