@@ -48,6 +48,12 @@ public class Configs {
   public static final String ENTITY_RELATIONAL_JDBC_BACKEND_PASSWORD_KEY =
       "gravitino.entity.store.relational.jdbcPassword";
 
+  public static final String ENTITY_RELATIONAL_JDBC_BACKEND_MAX_CONNECTION_KEYS =
+      "gravitino.entity.store.relational.maxConnections";
+
+  public static final String ENTITY_RELATIONAL_JDBC_BACKEND_MAX_WAIT_MILLIS_CONNECTION_KEY =
+      "gravitino.entity.store.relational.maxWaitMillis";
+
   public static final String ENTITY_RELATIONAL_JDBC_BACKEND_STORAGE_PATH_KEY =
       "gravitino.entity.store.relational.storagePath";
 
@@ -84,6 +90,10 @@ public class Configs {
 
   public static final String DEFAULT_RELATIONAL_JDBC_BACKEND_PASSWORD = "gravitino";
 
+  public static final int DEFAULT_RELATIONAL_JDBC_BACKEND_MAX_CONNECTIONS = 100;
+
+  public static final long DEFAULT_RELATIONAL_JDBC_BACKEND_MAX_WAIT_MILLISECONDS = 1000L;
+
   public static final int GARBAGE_COLLECTOR_SINGLE_DELETION_LIMIT = 100;
   public static final long MAX_NODE_IN_MEMORY = 100000L;
 
@@ -137,6 +147,21 @@ public class Configs {
           .stringConf()
           .createWithDefault(DEFAULT_RELATIONAL_JDBC_BACKEND_PASSWORD);
 
+  public static final ConfigEntry<Integer> ENTITY_RELATIONAL_JDBC_BACKEND_MAX_CONNECTIONS =
+      new ConfigBuilder(ENTITY_RELATIONAL_JDBC_BACKEND_MAX_CONNECTION_KEYS)
+          .doc("The maximum number of connections for the JDBC Backend connection pool")
+          .version(ConfigConstants.VERSION_0_9_0)
+          .intConf()
+          .createWithDefault(DEFAULT_RELATIONAL_JDBC_BACKEND_MAX_CONNECTIONS);
+
+  public static final ConfigEntry<Long> ENTITY_RELATIONAL_JDBC_BACKEND_WAIT_MILLISECONDS =
+      new ConfigBuilder(ENTITY_RELATIONAL_JDBC_BACKEND_MAX_WAIT_MILLIS_CONNECTION_KEY)
+          .doc(
+              "The maximum wait time in milliseconds for a connection from the JDBC Backend connection pool")
+          .version(ConfigConstants.VERSION_0_9_0)
+          .longConf()
+          .createWithDefault(DEFAULT_RELATIONAL_JDBC_BACKEND_MAX_WAIT_MILLISECONDS);
+
   public static final ConfigEntry<String> ENTITY_RELATIONAL_JDBC_BACKEND_PATH =
       new ConfigBuilder(ENTITY_RELATIONAL_JDBC_BACKEND_STORAGE_PATH_KEY)
           .doc(
@@ -310,4 +335,12 @@ public class Configs {
           .version(ConfigConstants.VERSION_0_7_0)
           .stringConf()
           .createWithDefault(SimpleFormatterV2.class.getName());
+
+  public static final ConfigEntry<List<String>> VISIBLE_CONFIGS =
+      new ConfigBuilder("gravitino.server.visibleConfigs")
+          .doc("List of configs that are visible in the config servlet")
+          .version(ConfigConstants.VERSION_0_9_0)
+          .stringConf()
+          .toSequence()
+          .createWithDefault(Collections.emptyList());
 }
