@@ -60,12 +60,12 @@ public class OwnerManager {
 
   public void setOwner(
       String metalake, MetadataObject metadataObject, String ownerName, Owner.Type ownerType) {
+
+    NameIdentifier objectIdent = MetadataObjectUtil.toEntityIdent(metalake, metadataObject);
     try {
       Optional<Owner> originOwner = getOwner(metalake, metadataObject);
 
-      NameIdentifier objectIdent = MetadataObjectUtil.toEntityIdent(metalake, metadataObject);
       OwnerImpl newOwner = new OwnerImpl();
-
       if (ownerType == Owner.Type.USER) {
         NameIdentifier ownerIdent = AuthorizationUtils.ofUser(metalake, ownerName);
         TreeLockUtils.doWithTreeLock(
@@ -129,16 +129,20 @@ public class OwnerManager {
   }
 
   public Optional<Owner> getOwner(String metalake, MetadataObject metadataObject) {
+    NameIdentifier ident = MetadataObjectUtil.toEntityIdent(metalake, metadataObject);
+    OwnerImpl owner = new OwnerImpl();
     try {
-      OwnerImpl owner = new OwnerImpl();
-      NameIdentifier ident = MetadataObjectUtil.toEntityIdent(metalake, metadataObject);
       List<? extends Entity> entities =
-          store
-              .relationOperations()
-              .listEntitiesByRelation(
-                  SupportsRelationOperations.Type.OWNER_REL,
-                  ident,
-                  MetadataObjectUtil.toEntityType(metadataObject));
+          TreeLockUtils.doWithTreeLock(
+              ident,
+              LockType.READ,
+              () ->
+                  store
+                      .relationOperations()
+                      .listEntitiesByRelation(
+                          SupportsRelationOperations.Type.OWNER_REL,
+                          ident,
+                          MetadataObjectUtil.toEntityType(metadataObject)));
 
       if (entities.isEmpty()) {
         return Optional.empty();
@@ -146,7 +150,7 @@ public class OwnerManager {
 
       if (entities.size() != 1) {
         throw new IllegalStateException(
-            String.format("The number of the owner %s must be 1", metadataObject.fullName()));
+            String.format("The size of the owner's name %s must be 1", metadataObject.fullName()));
       }
 
       Entity entity = entities.get(0);
