@@ -40,6 +40,14 @@ public final class EntityCombinedFileset implements Fileset {
     this.filesetEntity = filesetEntity;
   }
 
+  public FilesetEntity filesetEntity() {
+    return filesetEntity;
+  }
+
+  public Fileset fileset() {
+    return fileset;
+  }
+
   public static EntityCombinedFileset of(Fileset fileset, FilesetEntity filesetEntity) {
     return new EntityCombinedFileset(fileset, filesetEntity);
   }
@@ -69,14 +77,15 @@ public final class EntityCombinedFileset implements Fileset {
   }
 
   @Override
-  public String storageLocation() {
-    return fileset.storageLocation();
+  public Map<String, String> storageLocations() {
+    return fileset.storageLocations();
   }
 
   @Override
   public Map<String, String> properties() {
     return fileset.properties().entrySet().stream()
         .filter(p -> !hiddenProperties.contains(p.getKey()))
+        .filter(entry -> entry.getKey() != null && entry.getValue() != null)
         .collect(Collectors.toMap(Map.Entry::getKey, Map.Entry::getValue));
   }
 
