@@ -29,6 +29,7 @@ import org.apache.gravitino.Namespace;
 import org.apache.gravitino.connector.capability.Capability;
 import org.apache.gravitino.exceptions.FilesetAlreadyExistsException;
 import org.apache.gravitino.exceptions.NoSuchFilesetException;
+import org.apache.gravitino.exceptions.NoSuchLocationNameException;
 import org.apache.gravitino.exceptions.NoSuchSchemaException;
 import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.file.FilesetChange;
@@ -66,15 +67,15 @@ public class FilesetNormalizeDispatcher implements FilesetDispatcher {
   }
 
   @Override
-  public Fileset createFileset(
+  public Fileset createMultipleLocationFileset(
       NameIdentifier ident,
       String comment,
       Fileset.Type type,
-      String storageLocation,
+      Map<String, String> storageLocations,
       Map<String, String> properties)
       throws NoSuchSchemaException, FilesetAlreadyExistsException {
-    return dispatcher.createFileset(
-        normalizeNameIdentifier(ident), comment, type, storageLocation, properties);
+    return dispatcher.createMultipleLocationFileset(
+        normalizeNameIdentifier(ident), comment, type, storageLocations, properties);
   }
 
   @Override
@@ -95,10 +96,11 @@ public class FilesetNormalizeDispatcher implements FilesetDispatcher {
   }
 
   @Override
-  public String getFileLocation(NameIdentifier ident, String subPath) {
+  public String getFileLocation(NameIdentifier ident, String subPath, String locationName)
+      throws NoSuchFilesetException, NoSuchLocationNameException {
     // The constraints of the name spec may be more strict than underlying catalog,
     // and for compatibility reasons, we only apply case-sensitive capabilities here.
-    return dispatcher.getFileLocation(normalizeCaseSensitive(ident), subPath);
+    return dispatcher.getFileLocation(normalizeCaseSensitive(ident), subPath, locationName);
   }
 
   private NameIdentifier normalizeNameIdentifier(NameIdentifier ident) {
