@@ -20,12 +20,21 @@ package org.apache.gravitino.metalake;
 
 import static org.apache.gravitino.Metalake.PROPERTY_IN_USE;
 
+import com.github.benmanes.caffeine.cache.Cache;
+import com.github.benmanes.caffeine.cache.Caffeine;
+import com.github.benmanes.caffeine.cache.Scheduler;
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Maps;
+import com.google.common.util.concurrent.ThreadFactoryBuilder;
+import java.io.Closeable;
 import java.io.IOException;
 import java.time.Instant;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
 import org.apache.gravitino.Entity.EntityType;
 import org.apache.gravitino.EntityAlreadyExistsException;
 import org.apache.gravitino.EntityStore;
@@ -40,17 +49,20 @@ import org.apache.gravitino.exceptions.NoSuchEntityException;
 import org.apache.gravitino.exceptions.NoSuchMetalakeException;
 import org.apache.gravitino.exceptions.NonEmptyEntityException;
 import org.apache.gravitino.exceptions.NonEmptyMetalakeException;
+import org.apache.gravitino.lock.LockType;
+import org.apache.gravitino.lock.TreeLockUtils;
 import org.apache.gravitino.meta.AuditInfo;
 import org.apache.gravitino.meta.BaseMetalake;
 import org.apache.gravitino.meta.CatalogEntity;
 import org.apache.gravitino.meta.SchemaVersion;
 import org.apache.gravitino.storage.IdGenerator;
+import org.apache.gravitino.utils.Executable;
 import org.apache.gravitino.utils.PrincipalUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /** Manages Metalakes within the Apache Gravitino system. */
-public class MetalakeManager implements MetalakeDispatcher {
+public class MetalakeManager implements MetalakeDispatcher, Closeable {
 
   private static final String METALAKE_DOES_NOT_EXIST_MSG = "Metalake %s does not exist";
 
@@ -60,6 +72,28 @@ public class MetalakeManager implements MetalakeDispatcher {
 
   private final IdGenerator idGenerator;
 
+  // Currently, there will be only one MetalakeManager instance in the system. In this case
+  // we can clear or close the cache when the instance is destroyed.
+  @VisibleForTesting
+  static final Cache<NameIdentifier, BaseMetalake> METALAKE_CACHE =
+      Caffeine.newBuilder()
+          .expireAfterAccess(24, TimeUnit.HOURS)
+          .removalListener((k, v, c) -> LOG.info("Closing metalake {}.", k))
+          .scheduler(
+              Scheduler.forScheduledExecutorService(
+                  new ScheduledThreadPoolExecutor(
+                      1,
+                      new ThreadFactoryBuilder()
+                          .setDaemon(true)
+                          .setNameFormat("metalake-cleaner-%d")
+                          .build())))
+          .build();
+
+  @Override
+  public void close() {
+    METALAKE_CACHE.invalidateAll();
+  }
+
   /**
    * Constructs a MetalakeManager instance.
    *
@@ -69,6 +103,13 @@ public class MetalakeManager implements MetalakeDispatcher {
   public MetalakeManager(EntityStore store, IdGenerator idGenerator) {
     this.store = store;
     this.idGenerator = idGenerator;
+
+    // pre-load all metalakes and put them into cache, this is useful when user load schema/table
+    // directly without list/get metalake first.
+    BaseMetalake[] metalakes = listMetalakes();
+    for (BaseMetalake metalake : metalakes) {
+      METALAKE_CACHE.put(metalake.nameIdentifier(), metalake);
+    }
   }
 
   /**
@@ -99,10 +140,12 @@ public class MetalakeManager implements MetalakeDispatcher {
   public static boolean metalakeInUse(EntityStore store, NameIdentifier ident)
       throws NoSuchMetalakeException {
     try {
-      BaseMetalake metalake = store.get(ident, EntityType.METALAKE, BaseMetalake.class);
+      BaseMetalake metalake = METALAKE_CACHE.getIfPresent(ident);
+      if (metalake == null) {
+        metalake = store.get(ident, EntityType.METALAKE, BaseMetalake.class);
+      }
       return (boolean)
           metalake.propertiesMetadata().getOrDefault(metalake.properties(), PROPERTY_IN_USE);
-
     } catch (NoSuchEntityException e) {
       LOG.warn("Metalake {} does not exist", ident, e);
       throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, ident);
@@ -122,7 +165,12 @@ public class MetalakeManager implements MetalakeDispatcher {
   @Override
   public BaseMetalake[] listMetalakes() {
     try {
-      return store.list(Namespace.empty(), BaseMetalake.class, EntityType.METALAKE).stream()
+      List<BaseMetalake> metalakes =
+          TreeLockUtils.doWithRootTreeLock(
+              LockType.READ,
+              () -> store.list(Namespace.empty(), BaseMetalake.class, EntityType.METALAKE));
+
+      return metalakes.stream()
           .map(this::newMetalakeWithResolvedProperties)
           .toArray(BaseMetalake[]::new);
     } catch (IOException ioe) {
@@ -130,7 +178,6 @@ public class MetalakeManager implements MetalakeDispatcher {
       throw new RuntimeException(ioe);
     }
   }
-
   /**
    * Loads a Metalake.
    *
@@ -141,16 +188,25 @@ public class MetalakeManager implements MetalakeDispatcher {
    */
   @Override
   public BaseMetalake loadMetalake(NameIdentifier ident) throws NoSuchMetalakeException {
-    try {
-      return newMetalakeWithResolvedProperties(
-          store.get(ident, EntityType.METALAKE, BaseMetalake.class));
-    } catch (NoSuchEntityException e) {
-      LOG.warn("Metalake {} does not exist", ident, e);
-      throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, ident);
-    } catch (IOException ioe) {
-      LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
-      throw new RuntimeException(ioe);
-    }
+    return TreeLockUtils.doWithTreeLock(
+        ident,
+        LockType.READ,
+        () ->
+            METALAKE_CACHE.get(
+                ident,
+                k -> {
+                  try {
+                    BaseMetalake baseMetalake =
+                        store.get(ident, EntityType.METALAKE, BaseMetalake.class);
+                    return newMetalakeWithResolvedProperties(baseMetalake);
+                  } catch (NoSuchEntityException e) {
+                    LOG.warn("Metalake {} does not exist", ident, e);
+                    throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, ident);
+                  } catch (IOException ioe) {
+                    LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
+                    throw new RuntimeException(ioe);
+                  }
+                }));
   }
 
   private BaseMetalake newMetalakeWithResolvedProperties(BaseMetalake metalakeEntity) {
@@ -205,16 +261,21 @@ public class MetalakeManager implements MetalakeDispatcher {
                     .build())
             .build();
 
-    try {
-      store.put(metalake, false /* overwritten */);
-      return metalake;
-    } catch (EntityAlreadyExistsException | AlreadyExistsException e) {
-      LOG.warn("Metalake {} already exists", ident, e);
-      throw new MetalakeAlreadyExistsException("Metalake %s already exists", ident);
-    } catch (IOException ioe) {
-      LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
-      throw new RuntimeException(ioe);
-    }
+    return TreeLockUtils.doWithRootTreeLock(
+        LockType.WRITE,
+        () -> {
+          try {
+            store.put(metalake, false /* overwritten */);
+            METALAKE_CACHE.put(ident, newMetalakeWithResolvedProperties(metalake));
+            return metalake;
+          } catch (EntityAlreadyExistsException | AlreadyExistsException e) {
+            LOG.warn("Metalake {} already exists", ident, e);
+            throw new MetalakeAlreadyExistsException("Metalake %s already exists", ident);
+          } catch (IOException ioe) {
+            LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
+            throw new RuntimeException(ioe);
+          }
+        });
   }
 
   /**
@@ -230,120 +291,158 @@ public class MetalakeManager implements MetalakeDispatcher {
   @Override
   public BaseMetalake alterMetalake(NameIdentifier ident, MetalakeChange... changes)
       throws NoSuchMetalakeException, IllegalArgumentException {
-    try {
-      if (!metalakeInUse(store, ident)) {
-        throw new MetalakeNotInUseException(
-            "Metalake %s is not in use, please enable it first", ident);
-      }
+    Executable<BaseMetalake, RuntimeException> exceptionExecutable =
+        () -> {
+          try {
+            if (!metalakeInUse(store, ident)) {
+              throw new MetalakeNotInUseException(
+                  "Metalake %s is not in use, please enable it first", ident);
+            }
+            METALAKE_CACHE.invalidate(ident);
+            BaseMetalake baseMetalake =
+                store.update(
+                    ident,
+                    BaseMetalake.class,
+                    EntityType.METALAKE,
+                    metalake -> {
+                      BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
+                      Map<String, String> newProps =
+                          metalake.properties() == null
+                              ? Maps.newHashMap()
+                              : Maps.newHashMap(metalake.properties());
+                      builder = updateEntity(builder, newProps, changes);
 
-      return store.update(
-          ident,
-          BaseMetalake.class,
-          EntityType.METALAKE,
-          metalake -> {
-            BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
-            Map<String, String> newProps =
-                metalake.properties() == null
-                    ? Maps.newHashMap()
-                    : Maps.newHashMap(metalake.properties());
-            builder = updateEntity(builder, newProps, changes);
+                      return builder.build();
+                    });
+            METALAKE_CACHE.put(
+                baseMetalake.nameIdentifier(), newMetalakeWithResolvedProperties(baseMetalake));
+            return baseMetalake;
+          } catch (NoSuchEntityException ne) {
+            LOG.warn("Metalake {} does not exist", ident, ne);
+            throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, ident);
 
-            return builder.build();
-          });
+          } catch (IllegalArgumentException iae) {
+            LOG.warn("Altering Metalake {} failed due to invalid changes", ident, iae);
+            throw iae;
 
-    } catch (NoSuchEntityException ne) {
-      LOG.warn("Metalake {} does not exist", ident, ne);
-      throw new NoSuchMetalakeException(METALAKE_DOES_NOT_EXIST_MSG, ident);
+          } catch (IOException ioe) {
+            LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
+            throw new RuntimeException(ioe);
+          }
+        };
 
-    } catch (IllegalArgumentException iae) {
-      LOG.warn("Altering Metalake {} failed due to invalid changes", ident, iae);
-      throw iae;
-
-    } catch (IOException ioe) {
-      LOG.error("Loading Metalake {} failed due to storage issues", ident, ioe);
-      throw new RuntimeException(ioe);
+    boolean containsRenameMetalake =
+        Arrays.stream(changes).anyMatch(c -> c instanceof MetalakeChange.RenameMetalake);
+    if (containsRenameMetalake) {
+      return TreeLockUtils.doWithRootTreeLock(LockType.WRITE, exceptionExecutable);
     }
+
+    return TreeLockUtils.doWithTreeLock(ident, LockType.WRITE, exceptionExecutable);
   }
 
   @Override
   public boolean dropMetalake(NameIdentifier ident, boolean force)
       throws NonEmptyEntityException, MetalakeInUseException {
-    try {
-      boolean inUse = metalakeInUse(store, ident);
-      if (inUse && !force) {
-        throw new MetalakeInUseException(
-            "Metalake %s is in use, please disable it first or use force option", ident);
-      }
+    return TreeLockUtils.doWithRootTreeLock(
+        LockType.WRITE,
+        () -> {
+          try {
+            boolean inUse = metalakeInUse(store, ident);
+            if (inUse && !force) {
+              throw new MetalakeInUseException(
+                  "Metalake %s is in use, please disable it first or use force option", ident);
+            }
 
-      List<CatalogEntity> catalogEntities =
-          store.list(Namespace.of(ident.name()), CatalogEntity.class, EntityType.CATALOG);
-      if (!catalogEntities.isEmpty() && !force) {
-        throw new NonEmptyMetalakeException(
-            "Metalake %s has catalogs, please drop them first or use force option", ident);
-      }
+            METALAKE_CACHE.invalidate(ident);
 
-      return store.delete(ident, EntityType.METALAKE, true);
-    } catch (NoSuchMetalakeException e) {
-      return false;
+            List<CatalogEntity> catalogEntities =
+                store.list(Namespace.of(ident.name()), CatalogEntity.class, EntityType.CATALOG);
+            if (!catalogEntities.isEmpty() && !force) {
+              throw new NonEmptyMetalakeException(
+                  "Metalake %s has catalogs, please drop them first or use force option", ident);
+            }
 
-    } catch (IOException e) {
-      throw new RuntimeException(e);
-    }
+            return store.delete(ident, EntityType.METALAKE, true);
+          } catch (NoSuchMetalakeException e) {
+            return false;
+
+          } catch (IOException e) {
+            throw new RuntimeException(e);
+          }
+        });
   }
 
   @Override
   public void enableMetalake(NameIdentifier ident) throws NoSuchMetalakeException {
-    try {
+    TreeLockUtils.doWithTreeLock(
+        ident,
+        LockType.WRITE,
+        () -> {
+          try {
+            boolean inUse = metalakeInUse(store, ident);
+            if (!inUse) {
+              METALAKE_CACHE.invalidate(ident);
+              BaseMetalake baseMetalake =
+                  store.update(
+                      ident,
+                      BaseMetalake.class,
+                      EntityType.METALAKE,
+                      metalake -> {
+                        BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
 
-      boolean inUse = metalakeInUse(store, ident);
-      if (!inUse) {
-        store.update(
-            ident,
-            BaseMetalake.class,
-            EntityType.METALAKE,
-            metalake -> {
-              BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
+                        Map<String, String> newProps =
+                            metalake.properties() == null
+                                ? Maps.newHashMap()
+                                : Maps.newHashMap(metalake.properties());
+                        newProps.put(PROPERTY_IN_USE, "true");
+                        builder.withProperties(newProps);
 
-              Map<String, String> newProps =
-                  metalake.properties() == null
-                      ? Maps.newHashMap()
-                      : Maps.newHashMap(metalake.properties());
-              newProps.put(PROPERTY_IN_USE, "true");
-              builder.withProperties(newProps);
+                        return builder.build();
+                      });
+              METALAKE_CACHE.put(ident, newMetalakeWithResolvedProperties(baseMetalake));
+            }
 
-              return builder.build();
-            });
-      }
-    } catch (IOException e) {
-      throw new RuntimeException(e);
-    }
+            return null;
+          } catch (IOException e) {
+            throw new RuntimeException(e);
+          }
+        });
   }
 
   @Override
   public void disableMetalake(NameIdentifier ident) throws NoSuchMetalakeException {
-    try {
-      boolean inUse = metalakeInUse(store, ident);
-      if (inUse) {
-        store.update(
-            ident,
-            BaseMetalake.class,
-            EntityType.METALAKE,
-            metalake -> {
-              BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
+    TreeLockUtils.doWithTreeLock(
+        ident,
+        LockType.WRITE,
+        () -> {
+          try {
+            boolean inUse = metalakeInUse(store, ident);
+            if (inUse) {
+              METALAKE_CACHE.invalidate(ident);
+              BaseMetalake baseMetalake =
+                  store.update(
+                      ident,
+                      BaseMetalake.class,
+                      EntityType.METALAKE,
+                      metalake -> {
+                        BaseMetalake.Builder builder = newMetalakeBuilder(metalake);
 
-              Map<String, String> newProps =
-                  metalake.properties() == null
-                      ? Maps.newHashMap()
-                      : Maps.newHashMap(metalake.properties());
-              newProps.put(PROPERTY_IN_USE, "false");
-              builder.withProperties(newProps);
+                        Map<String, String> newProps =
+                            metalake.properties() == null
+                                ? Maps.newHashMap()
+                                : Maps.newHashMap(metalake.properties());
+                        newProps.put(PROPERTY_IN_USE, "false");
+                        builder.withProperties(newProps);
 
-              return builder.build();
-            });
-      }
-    } catch (IOException e) {
-      throw new RuntimeException(e);
-    }
+                        return builder.build();
+                      });
+              METALAKE_CACHE.put(ident, newMetalakeWithResolvedProperties(baseMetalake));
+            }
+            return null;
+          } catch (IOException e) {
+            throw new RuntimeException(e);
+          }
+        });
   }
 
   private BaseMetalake.Builder newMetalakeBuilder(BaseMetalake metalake) {
