@@ -22,6 +22,9 @@ import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Lists;
 import java.io.IOException;
 import java.time.Instant;
+import java.util.ArrayList;
+import java.util.Comparator;
+import org.apache.gravitino.MetadataObject;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.authorization.AuthorizationUtils;
 import org.apache.gravitino.authorization.Privileges;
@@ -31,6 +34,7 @@ import org.apache.gravitino.meta.AuditInfo;
 import org.apache.gravitino.meta.BaseMetalake;
 import org.apache.gravitino.meta.CatalogEntity;
 import org.apache.gravitino.meta.FilesetEntity;
+import org.apache.gravitino.meta.ModelEntity;
 import org.apache.gravitino.meta.RoleEntity;
 import org.apache.gravitino.meta.SchemaEntity;
 import org.apache.gravitino.meta.TableEntity;
@@ -49,9 +53,13 @@ public class TestSecurableObjects extends TestJDBCBackend {
     AuditInfo auditInfo =
         AuditInfo.builder().withCreator("creator").withCreateTime(Instant.now()).build();
     BaseMetalake metalake =
-        createBaseMakeLake(RandomIdGenerator.INSTANCE.nextId(), metalakeName, auditInfo);
+        createBaseMakeLake(RandomIdGenerator.INSTANCE.nextId(), metalakeName + "2", auditInfo);
     backend.insert(metalake, false);
 
+    BaseMetalake metalake2 =
+        createBaseMakeLake(RandomIdGenerator.INSTANCE.nextId(), metalakeName, auditInfo);
+    backend.insert(metalake2, false);
+
     CatalogEntity catalog =
         createCatalog(
             RandomIdGenerator.INSTANCE.nextId(), Namespace.of("metalake"), "catalog", auditInfo);
@@ -72,6 +80,7 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "fileset",
             auditInfo);
     backend.insert(fileset, false);
+
     TableEntity table =
         createTableEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -79,6 +88,7 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "table",
             auditInfo);
     backend.insert(table, false);
+
     TopicEntity topic =
         createTopicEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -87,6 +97,14 @@ public class TestSecurableObjects extends TestJDBCBackend {
             auditInfo);
     backend.insert(topic, false);
 
+    SecurableObject metalakeObject =
+        SecurableObjects.ofMetalake(
+            metalake.name(), Lists.newArrayList(Privileges.UseCatalog.allow()));
+
+    SecurableObject metalakeObject2 =
+        SecurableObjects.ofMetalake(
+            metalake2.name(), Lists.newArrayList(Privileges.UseCatalog.allow()));
+
     SecurableObject catalogObject =
         SecurableObjects.ofCatalog(
             "catalog",
@@ -95,24 +113,37 @@ public class TestSecurableObjects extends TestJDBCBackend {
     SecurableObject schemaObject =
         SecurableObjects.ofSchema(
             catalogObject, "schema", Lists.newArrayList(Privileges.UseSchema.allow()));
+
     SecurableObject tableObject =
         SecurableObjects.ofTable(
             schemaObject, "table", Lists.newArrayList(Privileges.SelectTable.allow()));
+
     SecurableObject filesetObject =
         SecurableObjects.ofFileset(
             schemaObject, "fileset", Lists.newArrayList(Privileges.ReadFileset.allow()));
+
     SecurableObject topicObject =
         SecurableObjects.ofTopic(
             schemaObject, "topic", Lists.newArrayList(Privileges.ConsumeTopic.deny()));
 
+    ArrayList<SecurableObject> securableObjects =
+        Lists.newArrayList(
+            metalakeObject,
+            metalakeObject2,
+            catalogObject,
+            schemaObject,
+            tableObject,
+            filesetObject,
+            topicObject);
+    securableObjects.sort(Comparator.comparing(MetadataObject::fullName));
+
     RoleEntity role1 =
         createRoleEntity(
             RandomIdGenerator.INSTANCE.nextId(),
             AuthorizationUtils.ofRoleNamespace(metalakeName),
             "role1",
             auditInfo,
-            Lists.newArrayList(
-                catalogObject, schemaObject, tableObject, filesetObject, topicObject),
+            securableObjects,
             ImmutableMap.of("k1", "v1"));
 
     Assertions.assertDoesNotThrow(() -> roleMetaService.insertRole(role1, false));
@@ -162,6 +193,16 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "topic",
             auditInfo);
     backend.insert(topic, false);
+    ModelEntity model =
+        createModelEntity(
+            RandomIdGenerator.INSTANCE.nextId(),
+            Namespace.of("metalake", "catalog", "schema"),
+            "model",
+            "comment",
+            1,
+            null,
+            auditInfo);
+    backend.insert(model, false);
 
     SecurableObject catalogObject =
         SecurableObjects.ofCatalog(
@@ -180,6 +221,9 @@ public class TestSecurableObjects extends TestJDBCBackend {
     SecurableObject topicObject =
         SecurableObjects.ofTopic(
             schemaObject, "topic", Lists.newArrayList(Privileges.ConsumeTopic.deny()));
+    SecurableObject modelObject =
+        SecurableObjects.ofModel(
+            schemaObject, "model", Lists.newArrayList(Privileges.UseModel.deny()));
 
     RoleEntity role1 =
         createRoleEntity(
@@ -188,37 +232,42 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "role1",
             auditInfo,
             Lists.newArrayList(
-                catalogObject, schemaObject, tableObject, filesetObject, topicObject),
+                catalogObject, schemaObject, tableObject, filesetObject, topicObject, modelObject),
             ImmutableMap.of("k1", "v1"));
 
     roleMetaService.insertRole(role1, false);
 
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countActiveObjectRel(role1.id()));
+
+    // Test to delete model
+    ModelMetaService.getInstance().deleteModel(model.nameIdentifier());
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(5, countActiveObjectRel(role1.id()));
 
     // Test to delete table
     TableMetaService.getInstance().deleteTable(table.nameIdentifier());
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(4, countActiveObjectRel(role1.id()));
 
     // Test to delete topic
     TopicMetaService.getInstance().deleteTopic(topic.nameIdentifier());
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(3, countActiveObjectRel(role1.id()));
 
     // Test to delete fileset
     FilesetMetaService.getInstance().deleteFileset(fileset.nameIdentifier());
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(2, countActiveObjectRel(role1.id()));
 
     // Test to delete schema
     SchemaMetaService.getInstance().deleteSchema(schema.nameIdentifier(), false);
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(1, countActiveObjectRel(role1.id()));
 
     // Test to delete catalog
     CatalogMetaService.getInstance().deleteCatalog(catalog.nameIdentifier(), false);
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(0, countActiveObjectRel(role1.id()));
 
     roleMetaService.deleteRole(role1.nameIdentifier());
@@ -251,6 +300,7 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "table",
             auditInfo);
     backend.insert(table, false);
+
     topic =
         createTopicEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -258,6 +308,18 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "topic",
             auditInfo);
     backend.insert(topic, false);
+
+    model =
+        createModelEntity(
+            RandomIdGenerator.INSTANCE.nextId(),
+            Namespace.of("metalake", "catalog", "schema"),
+            "model",
+            "comment",
+            1,
+            null,
+            auditInfo);
+    backend.insert(model, false);
+
     role1 =
         createRoleEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -265,13 +327,13 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "role1",
             auditInfo,
             Lists.newArrayList(
-                catalogObject, schemaObject, tableObject, filesetObject, topicObject),
+                catalogObject, schemaObject, tableObject, filesetObject, topicObject, modelObject),
             ImmutableMap.of("k1", "v1"));
 
     roleMetaService.insertRole(role1, false);
 
     CatalogMetaService.getInstance().deleteCatalog(catalog.nameIdentifier(), true);
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(0, countActiveObjectRel(role1.id()));
 
     roleMetaService.deleteRole(role1.nameIdentifier());
@@ -311,6 +373,17 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "topic",
             auditInfo);
     backend.insert(topic, false);
+    model =
+        createModelEntity(
+            RandomIdGenerator.INSTANCE.nextId(),
+            Namespace.of("metalake", "catalog", "schema"),
+            "model",
+            "comment",
+            1,
+            null,
+            auditInfo);
+    backend.insert(model, false);
+
     role1 =
         createRoleEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -318,13 +391,13 @@ public class TestSecurableObjects extends TestJDBCBackend {
             "role1",
             auditInfo,
             Lists.newArrayList(
-                catalogObject, schemaObject, tableObject, filesetObject, topicObject),
+                catalogObject, schemaObject, tableObject, filesetObject, topicObject, modelObject),
             ImmutableMap.of("k1", "v1"));
 
     roleMetaService.insertRole(role1, false);
 
     SchemaMetaService.getInstance().deleteSchema(schema.nameIdentifier(), true);
-    Assertions.assertEquals(5, countAllObjectRel(role1.id()));
+    Assertions.assertEquals(6, countAllObjectRel(role1.id()));
     Assertions.assertEquals(1, countActiveObjectRel(role1.id()));
   }
 }
