@@ -18,8 +18,13 @@
  */
 package org.apache.gravitino.server.web.rest;
 
+import static org.apache.gravitino.file.Fileset.LOCATION_NAME_UNKNOWN;
+
 import com.codahale.metrics.annotation.ResponseMetered;
 import com.codahale.metrics.annotation.Timed;
+import com.google.common.collect.ImmutableMap;
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Optional;
 import javax.inject.Inject;
@@ -49,8 +54,6 @@ import org.apache.gravitino.dto.responses.FilesetResponse;
 import org.apache.gravitino.dto.util.DTOConverters;
 import org.apache.gravitino.file.Fileset;
 import org.apache.gravitino.file.FilesetChange;
-import org.apache.gravitino.lock.LockType;
-import org.apache.gravitino.lock.TreeLockUtils;
 import org.apache.gravitino.metrics.MetricNames;
 import org.apache.gravitino.rest.RESTUtils;
 import org.apache.gravitino.server.web.Utils;
@@ -87,11 +90,7 @@ public class FilesetOperations {
           httpRequest,
           () -> {
             Namespace filesetNS = NamespaceUtil.ofFileset(metalake, catalog, schema);
-            NameIdentifier[] idents =
-                TreeLockUtils.doWithTreeLock(
-                    NameIdentifier.of(metalake, catalog, schema),
-                    LockType.READ,
-                    () -> dispatcher.listFilesets(filesetNS));
+            NameIdentifier[] idents = dispatcher.listFilesets(filesetNS);
             Response response = Utils.ok(new EntityListResponse(idents));
             LOG.info(
                 "List {} filesets under schema: {}.{}.{}",
@@ -130,17 +129,22 @@ public class FilesetOperations {
             NameIdentifier ident =
                 NameIdentifierUtil.ofFileset(metalake, catalog, schema, request.getName());
 
+            // set storageLocation value as unnamed location if provided
+            Map<String, String> tmpLocations =
+                new HashMap<>(
+                    Optional.ofNullable(request.getStorageLocations())
+                        .orElse(Collections.emptyMap()));
+            Optional.ofNullable(request.getStorageLocation())
+                .ifPresent(loc -> tmpLocations.put(LOCATION_NAME_UNKNOWN, loc));
+            Map<String, String> storageLocations = ImmutableMap.copyOf(tmpLocations);
+
             Fileset fileset =
-                TreeLockUtils.doWithTreeLock(
-                    NameIdentifierUtil.ofSchema(metalake, catalog, schema),
-                    LockType.WRITE,
-                    () ->
-                        dispatcher.createFileset(
-                            ident,
-                            request.getComment(),
-                            Optional.ofNullable(request.getType()).orElse(Fileset.Type.MANAGED),
-                            request.getStorageLocation(),
-                            request.getProperties()));
+                dispatcher.createMultipleLocationFileset(
+                    ident,
+                    request.getComment(),
+                    Optional.ofNullable(request.getType()).orElse(Fileset.Type.MANAGED),
+                    storageLocations,
+                    request.getProperties());
             Response response = Utils.ok(new FilesetResponse(DTOConverters.toDTO(fileset)));
             LOG.info("Fileset created: {}.{}.{}.{}", metalake, catalog, schema, request.getName());
             return response;
@@ -168,9 +172,7 @@ public class FilesetOperations {
           httpRequest,
           () -> {
             NameIdentifier ident = NameIdentifierUtil.ofFileset(metalake, catalog, schema, fileset);
-            Fileset t =
-                TreeLockUtils.doWithTreeLock(
-                    ident, LockType.READ, () -> dispatcher.loadFileset(ident));
+            Fileset t = dispatcher.loadFileset(ident);
             Response response = Utils.ok(new FilesetResponse(DTOConverters.toDTO(t)));
             LOG.info("Fileset loaded: {}.{}.{}.{}", metalake, catalog, schema, fileset);
             return response;
@@ -202,11 +204,7 @@ public class FilesetOperations {
                 request.getUpdates().stream()
                     .map(FilesetUpdateRequest::filesetChange)
                     .toArray(FilesetChange[]::new);
-            Fileset t =
-                TreeLockUtils.doWithTreeLock(
-                    NameIdentifierUtil.ofSchema(metalake, catalog, schema),
-                    LockType.WRITE,
-                    () -> dispatcher.alterFileset(ident, changes));
+            Fileset t = dispatcher.alterFileset(ident, changes);
             Response response = Utils.ok(new FilesetResponse(DTOConverters.toDTO(t)));
             LOG.info("Fileset altered: {}.{}.{}.{}", metalake, catalog, schema, t.name());
             return response;
@@ -233,11 +231,7 @@ public class FilesetOperations {
           httpRequest,
           () -> {
             NameIdentifier ident = NameIdentifierUtil.ofFileset(metalake, catalog, schema, fileset);
-            boolean dropped =
-                TreeLockUtils.doWithTreeLock(
-                    NameIdentifierUtil.ofSchema(metalake, catalog, schema),
-                    LockType.WRITE,
-                    () -> dispatcher.dropFileset(ident));
+            boolean dropped = dispatcher.dropFileset(ident);
             if (!dropped) {
               LOG.warn("Failed to drop fileset {} under schema {}", fileset, schema);
             }
@@ -262,14 +256,16 @@ public class FilesetOperations {
       @PathParam("catalog") String catalog,
       @PathParam("schema") String schema,
       @PathParam("fileset") String fileset,
-      @QueryParam("sub_path") @NotNull String subPath) {
+      @QueryParam("sub_path") @NotNull String subPath,
+      @QueryParam("location_name") String locationName) {
     LOG.info(
-        "Received get file location request: {}.{}.{}.{}, sub path:{}",
+        "Received get file location request: {}.{}.{}.{}, sub path:{}, location name:{}",
         metalake,
         catalog,
         schema,
         fileset,
-        RESTUtils.decodeString(subPath));
+        RESTUtils.decodeString(subPath),
+        Optional.ofNullable(locationName).map(RESTUtils::decodeString).orElse(null));
     try {
       return Utils.doAs(
           httpRequest,
@@ -283,10 +279,10 @@ public class FilesetOperations {
               CallerContext.CallerContextHolder.set(context);
             }
             String actualFileLocation =
-                TreeLockUtils.doWithTreeLock(
+                dispatcher.getFileLocation(
                     ident,
-                    LockType.READ,
-                    () -> dispatcher.getFileLocation(ident, RESTUtils.decodeString(subPath)));
+                    RESTUtils.decodeString(subPath),
+                    Optional.ofNullable(locationName).map(RESTUtils::decodeString).orElse(null));
             return Utils.ok(new FileLocationResponse(actualFileLocation));
           });
     } catch (Exception e) {
