@@ -26,6 +26,7 @@ import static org.mockito.Mockito.when;
 import com.google.common.collect.ImmutableMap;
 import java.io.IOException;
 import java.time.Instant;
+import java.util.Collections;
 import java.util.Map;
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.client.Entity;
@@ -35,8 +36,13 @@ import javax.ws.rs.core.Response;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.catalog.ModelDispatcher;
+import org.apache.gravitino.dto.model.ModelVersionDTO;
 import org.apache.gravitino.dto.requests.ModelRegisterRequest;
+import org.apache.gravitino.dto.requests.ModelUpdateRequest;
+import org.apache.gravitino.dto.requests.ModelUpdatesRequest;
 import org.apache.gravitino.dto.requests.ModelVersionLinkRequest;
+import org.apache.gravitino.dto.requests.ModelVersionUpdateRequest;
+import org.apache.gravitino.dto.requests.ModelVersionUpdatesRequest;
 import org.apache.gravitino.dto.responses.BaseResponse;
 import org.apache.gravitino.dto.responses.DropResponse;
 import org.apache.gravitino.dto.responses.EntityListResponse;
@@ -50,7 +56,9 @@ import org.apache.gravitino.exceptions.NoSuchModelException;
 import org.apache.gravitino.exceptions.NoSuchSchemaException;
 import org.apache.gravitino.meta.AuditInfo;
 import org.apache.gravitino.model.Model;
+import org.apache.gravitino.model.ModelChange;
 import org.apache.gravitino.model.ModelVersion;
+import org.apache.gravitino.model.ModelVersionChange;
 import org.apache.gravitino.rest.RESTUtils;
 import org.apache.gravitino.utils.NameIdentifierUtil;
 import org.apache.gravitino.utils.NamespaceUtil;
@@ -792,6 +800,255 @@ public class TestModelOperations extends JerseyTest {
     Assertions.assertEquals(RuntimeException.class.getSimpleName(), errorResp2.getType());
   }
 
+  @Test
+  public void testRenameModel() {
+    String oldName = "model1";
+    String newName = "newModel1";
+    String comment = "comment";
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, oldName);
+    Model updatedModel = mockModel(newName, comment, 0);
+
+    // Mock alterModel to return updated model
+    when(modelDispatcher.alterModel(modelId, new ModelChange[] {ModelChange.rename(newName)}))
+        .thenReturn(updatedModel);
+
+    // Build update request
+    ModelUpdatesRequest req =
+        new ModelUpdatesRequest(
+            Collections.singletonList(new ModelUpdateRequest.RenameModelRequest(newName)));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelResponse modelResp = resp.readEntity(ModelResponse.class);
+    Assertions.assertEquals(comment, modelResp.getModel().comment());
+    Assertions.assertEquals(newName, modelResp.getModel().name());
+
+    // Test NoSuchModelException
+    doThrow(new NoSuchModelException("mock error"))
+        .when(modelDispatcher)
+        .alterModel(modelId, new ModelChange[] {ModelChange.rename(newName)});
+
+    Response resp1 =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.NOT_FOUND.getStatusCode(), resp1.getStatus());
+    ErrorResponse errorResp = resp1.readEntity(ErrorResponse.class);
+    Assertions.assertEquals(ErrorConstants.NOT_FOUND_CODE, errorResp.getCode());
+
+    // Test RuntimeException
+    doThrow(new RuntimeException("mock error"))
+        .when(modelDispatcher)
+        .alterModel(modelId, new ModelChange[] {ModelChange.rename(newName)});
+
+    Response resp2 =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(
+        Response.Status.INTERNAL_SERVER_ERROR.getStatusCode(), resp2.getStatus());
+    ErrorResponse errorResp1 = resp2.readEntity(ErrorResponse.class);
+    Assertions.assertEquals(ErrorConstants.INTERNAL_ERROR_CODE, errorResp1.getCode());
+  }
+
+  @Test
+  void testAddModelProperty() {
+    String modelName = "model1";
+    String comment = "comment";
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, modelName);
+    Model updatedModel =
+        mockModel(
+            modelName,
+            comment,
+            0,
+            ImmutableMap.<String, String>builder()
+                .putAll(properties)
+                .put("key2", "value2")
+                .build());
+
+    // Mock alterModel to return updated model
+    when(modelDispatcher.alterModel(
+            modelId, new ModelChange[] {ModelChange.setProperty("key2", "value2")}))
+        .thenReturn(updatedModel);
+
+    // Build update request
+    ModelUpdatesRequest req =
+        new ModelUpdatesRequest(
+            Collections.singletonList(
+                new ModelUpdateRequest.SetModelPropertyRequest("key2", "value2")));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelResponse modelResp = resp.readEntity(ModelResponse.class);
+    Assertions.assertEquals(comment, modelResp.getModel().comment());
+    Assertions.assertEquals(modelName, modelResp.getModel().name());
+    Assertions.assertEquals(2, modelResp.getModel().properties().size());
+    Assertions.assertEquals("value2", modelResp.getModel().properties().get("key2"));
+  }
+
+  @Test
+  void testUpdateModelProperty() {
+    String modelName = "model1";
+    String comment = "comment";
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, modelName);
+    Model updatedModel = mockModel(modelName, comment, 0, ImmutableMap.of("key1", "updatedValue1"));
+
+    // Mock alterModel to return updated model
+    when(modelDispatcher.alterModel(modelId, ModelChange.setProperty("key1", "updatedValue1")))
+        .thenReturn(updatedModel);
+
+    // Build update request
+    ModelUpdatesRequest req =
+        new ModelUpdatesRequest(
+            Collections.singletonList(
+                new ModelUpdateRequest.SetModelPropertyRequest("key1", "updatedValue1")));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelResponse modelResp = resp.readEntity(ModelResponse.class);
+    Assertions.assertEquals(comment, modelResp.getModel().comment());
+    Assertions.assertEquals(modelName, modelResp.getModel().name());
+    Assertions.assertEquals(1, modelResp.getModel().properties().size());
+    Assertions.assertEquals("updatedValue1", modelResp.getModel().properties().get("key1"));
+  }
+
+  @Test
+  void testRemoveModelProperty() {
+    String modelName = "model1";
+    String comment = "comment";
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, modelName);
+    Model updatedModel = mockModel(modelName, comment, 0, ImmutableMap.of());
+
+    // Mock alterModel to return updated model
+    when(modelDispatcher.alterModel(modelId, ModelChange.removeProperty("key1")))
+        .thenReturn(updatedModel);
+
+    // Build update request
+    ModelUpdatesRequest req =
+        new ModelUpdatesRequest(
+            Collections.singletonList(new ModelUpdateRequest.RemoveModelPropertyRequest("key1")));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelResponse modelResp = resp.readEntity(ModelResponse.class);
+    Assertions.assertEquals(comment, modelResp.getModel().comment());
+    Assertions.assertEquals(modelName, modelResp.getModel().name());
+    Assertions.assertEquals(0, modelResp.getModel().properties().size());
+    Assertions.assertFalse(modelResp.getModel().properties().containsKey("key1"));
+  }
+
+  @Test
+  void testUpdateModelVersionComment() {
+    String modelName = "model1";
+    String newComment = "new comment";
+    String uri = "uri1";
+    int version = 0;
+    String[] alias = new String[] {"alias1"};
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, modelName);
+    ModelVersion mockModelVersion = mockModelVersion(version, uri, alias, newComment);
+
+    when(modelDispatcher.alterModelVersion(
+            modelId, version, ModelVersionChange.updateComment(newComment)))
+        .thenReturn(mockModelVersion);
+
+    ModelVersionUpdatesRequest req =
+        new ModelVersionUpdatesRequest(
+            Collections.singletonList(
+                new ModelVersionUpdateRequest.UpdateModelVersionComment(newComment)));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .path("versions")
+            .path("0")
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelVersionResponse modelVersionResponse = resp.readEntity(ModelVersionResponse.class);
+    ModelVersionDTO modelVersion = modelVersionResponse.getModelVersion();
+
+    Assertions.assertEquals(newComment, modelVersion.comment());
+    Assertions.assertArrayEquals(alias, modelVersion.aliases());
+    Assertions.assertEquals(version, modelVersion.version());
+    Assertions.assertEquals(uri, modelVersion.uri());
+  }
+
+  @Test
+  void testUpdateModelVersionCommentByAlias() {
+    String modelName = "model1";
+    String newComment = "new comment";
+    String uri = "uri1";
+    int version = 0;
+    String[] alias = new String[] {"alias1"};
+
+    NameIdentifier modelId = NameIdentifierUtil.ofModel(metalake, catalog, schema, modelName);
+    ModelVersion mockModelVersion = mockModelVersion(version, uri, alias, newComment);
+
+    when(modelDispatcher.alterModelVersion(
+            modelId, alias[0], ModelVersionChange.updateComment(newComment)))
+        .thenReturn(mockModelVersion);
+
+    ModelVersionUpdatesRequest req =
+        new ModelVersionUpdatesRequest(
+            Collections.singletonList(
+                new ModelVersionUpdateRequest.UpdateModelVersionComment(newComment)));
+
+    Response resp =
+        target(modelPath())
+            .path("model1")
+            .path("aliases")
+            .path(alias[0])
+            .request(MediaType.APPLICATION_JSON_TYPE)
+            .accept("application/vnd.gravitino.v1+json")
+            .put(Entity.entity(req, MediaType.APPLICATION_JSON_TYPE));
+
+    Assertions.assertEquals(Response.Status.OK.getStatusCode(), resp.getStatus());
+    ModelVersionResponse modelVersionResponse = resp.readEntity(ModelVersionResponse.class);
+    ModelVersionDTO modelVersion = modelVersionResponse.getModelVersion();
+
+    Assertions.assertEquals(newComment, modelVersion.comment());
+    Assertions.assertArrayEquals(alias, modelVersion.aliases());
+    Assertions.assertEquals(version, modelVersion.version());
+    Assertions.assertEquals(uri, modelVersion.uri());
+  }
+
   private String modelPath() {
     return "/metalakes/" + metalake + "/catalogs/" + catalog + "/schemas/" + schema + "/models";
   }
@@ -806,6 +1063,17 @@ public class TestModelOperations extends JerseyTest {
     return mockModel;
   }
 
+  private Model mockModel(
+      String modelName, String comment, int latestVersion, Map<String, String> properties) {
+    Model mockModel = mock(Model.class);
+    when(mockModel.name()).thenReturn(modelName);
+    when(mockModel.comment()).thenReturn(comment);
+    when(mockModel.latestVersion()).thenReturn(latestVersion);
+    when(mockModel.properties()).thenReturn(properties);
+    when(mockModel.auditInfo()).thenReturn(testAuditInfo);
+    return mockModel;
+  }
+
   private ModelVersion mockModelVersion(int version, String uri, String[] aliases, String comment) {
     ModelVersion mockModelVersion = mock(ModelVersion.class);
     when(mockModelVersion.version()).thenReturn(version);
