@@ -109,6 +109,26 @@ public abstract class SparkIcebergCatalogIT extends SparkCommonIT {
     return true;
   }
 
+  @Override
+  protected boolean supportsSchemaAndTableProperties() {
+    return true;
+  }
+
+  @Override
+  protected boolean supportsComplexType() {
+    return true;
+  }
+
+  @Override
+  protected boolean supportsUpdateColumnPosition() {
+    return true;
+  }
+
+  @Override
+  protected boolean supportListTable() {
+    return true;
+  }
+
   @Override
   protected String getTableLocation(SparkTableInfo table) {
     return String.join(File.separator, table.getTableLocation(), "data");
